@@ -200,11 +200,11 @@ class Desktop(MethodsInterface):
         dirStart, dirEnd = path.split(homeDir)
         mountProfileDir = path.join(dirStart, ".%s" % dirEnd)
         mountRemoteProfileDir = path.join(dirStart, ".%s.remote" % dirEnd)
-        return filter(lambda x: x.startswith(homeDir) or
-                                x.startswith(mountProfileDir) or
-                                x.startswith(mountRemoteProfileDir),
-                      map(lambda x: x.split(" ")[1],
-                          open("/proc/mounts").readlines()))
+        with open("/proc/mounts") as f:
+            return filter(lambda x: x.startswith(homeDir) or
+                                    x.startswith(mountProfileDir) or
+                                    x.startswith(mountRemoteProfileDir),
+                          map(lambda x: x.split(" ")[1], f))
 
     def umountSleepPath(self, rpath):
         """
